@@ -1,26 +1,30 @@
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
 """Credentials Management for REST Endpoint
 """
 
-from __future__ import absolute_import
 
-from future import standard_library
-
-standard_library.install_aliases()
-from builtins import object
 import json
 import urllib.parse
-from solnlib.credentials import (
-    CredentialManager,
-    CredentialNotExistException,
-)
 
-from .util import get_base_app_name
+from solnlib.credentials import CredentialManager, CredentialNotExistException
+
 from .error import RestError
-
+from .util import get_base_app_name
 
 __all__ = [
     "RestCredentialsContext",
@@ -28,7 +32,7 @@ __all__ = [
 ]
 
 
-class RestCredentialsContext(object):
+class RestCredentialsContext:
     """
     Credentials' context, including realm, username and password.
     """
@@ -82,14 +86,14 @@ class RestCredentialsContext(object):
             raise RestError(500, "Fail to load encrypted string, invalid JSON")
 
 
-class RestCredentials(object):
+class RestCredentials:
     """
     Credential Management stored in passwords.conf
     """
 
     # Changed password constant to six '*' to make it consistent with solnlib password constant
-    PASSWORD = u"******"
-    EMPTY_VALUE = u""
+    PASSWORD = "******"
+    EMPTY_VALUE = ""
 
     def __init__(self, splunkd_uri, session_key, endpoint):
         self._splunkd_uri = splunkd_uri
