@@ -1,10 +1,19 @@
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
-from builtins import str
-from builtins import range
-from builtins import object
 import json
 import os
 
@@ -12,7 +21,6 @@ import solnlib.utils as utils
 
 from splunktaucclib.global_config import GlobalConfig, GlobalConfigSchema
 
-
 """
 Usage Examples:
 setup_util = Setup_Util(uri, session_key)
@@ -92,13 +100,13 @@ ALL_SETTING_TYPES = [
 
 def get_schema_path():
     dirname = os.path.dirname
-    basedir = dirname(dirname(dirname((dirname(__file__)))))
+    basedir = dirname(dirname(dirname(dirname(__file__))))
     return os.path.join(
         basedir, "appserver", "static", "js", "build", "globalConfig.json"
     )
 
 
-class Setup_Util(object):
+class Setup_Util:
     def __init__(self, uri, session_key, logger=None):
         self.__uri = uri
         self.__session_key = session_key
